About BioSimulators utils
=============================

License
-------
This package is released under the `MIT License <https://github.com/biosimulators/Biosimulators_utils/blob/dev/LICENSE>`_.

Development team
----------------
This package was developed by the `Karr Lab <https://www.karrlab.org>`_ at the Icahn School of Medicine at Mount Sinai and the `Center for Reproducible Biomedical Modeling <https://reproduciblebiomodels.org/>`_.

Contributing to BioSimulators utils
-----------------------------------
We enthusiastically welcome contributions to BioSimulators utils! Please see the `guide to contributing <https://github.com/biosimulators/Biosimulators_utils/blob/dev/CONTRIBUTING.md>`_ and the `developer's code of conduct <https://github.com/biosimulators/Biosimulators_utils/blob/dev/CODE_OF_CONDUCT.md>`_.

Acknowledgements
----------------
This work was supported by National Institutes of Health award P41EB023912.

Questions and comments
-------------------------
Please contact the `BioSimulators Team <mailto:info@biosimulators.org>`_ with any questions or comments.
